tonalanalysistools.ScaleDegree
==============================

.. abjad-lineage:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree

.. autoclass:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.accidental
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.apply_accidental
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.name
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.number
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.roman_numeral_string
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.symbolic_string
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.title_string
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__eq__
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__format__
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__ne__
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__repr__
      ~abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.accidental
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.number
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.roman_numeral_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.symbolic_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.title_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.apply_accidental
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ScaleDegree.ScaleDegree.__str__
   :noindex:
